@@ -3,6 +3,7 @@ from transformers import BertModel
 from transformersx.data import TaskDataProcessor
 from transformersx.task import DefaultTransformerTask, TaskConfig
 from transformersx.train import TaskContext
+from transformersx.transformersx_base import to_json_string
 
 
 class DefaultTransformerTaskForTest(DefaultTransformerTask):
@@ -24,5 +25,8 @@ class DefaultTransformerTaskForTest(DefaultTransformerTask):
 
 
 class Test_Transformersx_task:
+    def test_task_config(self):
+        print(to_json_string(TaskConfig()))
+
     def test_default_task(self):
         DefaultTransformerTaskForTest(TaskConfig())
